@@ -2,19 +2,20 @@
 
 package Dancer2::Core::Factory;
 {
-    $Dancer2::Core::Factory::VERSION = '0.07';
+    $Dancer2::Core::Factory::VERSION = '0.08';
 }
 use strict;
 use warnings;
 
+use Dancer2::Core;
 use Dancer2::ModuleLoader;
 use Carp 'croak';
 
 sub create {
     my ( $class, $type, $name, %options ) = @_;
 
-    $type = _camelize($type);
-    $name = _camelize($name);
+    $type = Dancer2::Core::camelize($type);
+    $name = Dancer2::Core::camelize($name);
     my $component_class = "Dancer2::${type}::${name}";
 
     my ( $ok, $error ) = Dancer2::ModuleLoader->require($component_class);
@@ -25,16 +26,6 @@ sub create {
     return $component_class->new(%options);
 }
 
-sub _camelize {
-    my ($value) = @_;
-
-    my $camelized = '';
-    for my $word ( split /_/, $value ) {
-        $camelized .= ucfirst($word);
-    }
-    return $camelized;
-}
-
 1;
 
 __END__
@@ -47,7 +38,7 @@ Dancer2::Core::Factory - Instantiate components by type and name
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 AUTHOR
 
