@@ -2,7 +2,7 @@
 
 package Dancer2::Logger::Capture;
 {
-    $Dancer2::Logger::Capture::VERSION = '0.07';
+    $Dancer2::Logger::Capture::VERSION = '0.08';
 }
 use Moo;
 use Dancer2::Logger::Capture::Trap;
@@ -37,25 +37,29 @@ Dancer2::Logger::Capture - Capture dancer logs
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
+The basics:
+
     set logger => "capture";
 
-    my $trap = Dancer2::Logger::Capture->trap;
+    my $trap = dancer_app->engine('logger')->trapper;
     my $logs = $trap->read;
 
-	#a real-world example
-    use Test::More import => ['!pass'], tests => 2;
-    use Dancer2;
+A worked-out real-world example:
+
+    use Test::More tests => 2;
+    use Dancer2 ':tests';
 
     set logger => 'capture';
 
     warning "Danger!  Warning!";
     debug   "I like pie.";
 
-    my $trap = Dancer2::Logger::Capture->trap;
+    my $trap = dancer_app->engine('logger')->trapper;
+
     is_deeply $trap->read, [
         { level => "warning", message => "Danger!  Warning!" },
         { level => "debug",   message => "I like pie.", }
@@ -79,7 +83,7 @@ and read logs.
 
 =head1 SEE ALSO
 
-L<Dancer2::Logger>, L<Dancer2::Logger::Capture::Trap>
+L<Dancer2::Core::Role::Logger>, L<Dancer2::Logger::Capture::Trap>
 
 =head1 AUTHOR
 
